import { IUser } from '../types/models/User';
import { HttpClient, HttpBackend } from '@angular/common/http';
import { Subject } from 'rxjs';
import { Router } from '@angular/router';
import { IReqUserUpdate } from '../types/requests/ReqUserUpdate';
import { StrapiAuthConfig, StrapiAuthProviders } from '../types/StrapiAuthConfig';
import { TranslateService } from '@ngx-translate/core';
import { IReqPasswordReset } from '../types/requests/ReqPasswordReset';
import * as i0 from "@angular/core";
export declare class AuthService {
    private httpClient;
    private handler;
    private router;
    private config;
    private apiUrl;
    private user;
    private token;
    private authHttpClient;
    private authState;
    private userState;
    isAuthenticated: boolean;
    readonly strapiAuthConfig: StrapiAuthConfig;
    constructor(httpClient: HttpClient, handler: HttpBackend, router: Router, config: StrapiAuthConfig);
    /**
     * Return AuthState Promise
     */
    get AuthState(): Subject<void>;
    /**
     * Return AuthState Promise
     */
    get UserState(): Subject<void>;
    /**
     * Return login redirect url
     */
    get LoginRedirectUrl(): string;
    /**
     * Return login url
     */
    get LoginUrl(): string;
    /**
     * Return logout url
     */
    get LogoutUrl(): string;
    /**
     * Return logout redirect url
     */
    get LogoutRedirectUrl(): string;
    /**
     * Return register url
     */
    get RegisterUrl(): string;
    /**
     * Return request password url
     */
    get RequestPasswordUrl(): string;
    /**
     * Return request password redirect url
     */
    get RequestPasswordRedirectUrl(): string;
    /**
     * Return reset password url
     */
    get ResetPasswordUrl(): string;
    /**
     * Set default translation for StrapiAuthModule
     */
    setDefaultTranslation(translate: TranslateService): Promise<void>;
    /**
     * Login user with given credentials
     * and store jwt token and user data
     */
    login(email: string, password: string): Promise<void>;
    /**
     * Login user using external provider
     * like google / facebook / microsoft / github
     */
    callbackProviderLogin(params: string, provider: StrapiAuthProviders): Promise<void>;
    /**
     * Register new user with given data
     *
     * If registration has jwt token and user data in response
     * then store token and show user as logged in
     *
     */
    register(email: string, username: string, password: string): Promise<void>;
    /**
     * Logout user
     */
    logout(): Promise<void>;
    /**
     * Update user profile
     */
    updateProfile(updateReq: IReqUserUpdate): Promise<void>;
    /**
     * Request password reset mail
     */
    requestPasswordReset(email: string): Promise<void>;
    /**
     * Reset user password
     */
    resetPassword(passwordResetReq: IReqPasswordReset): Promise<void>;
    /**
     * Return token if given
     */
    getToken(): string;
    /**
     * Set token variable and write token to local storage
     */
    setToken(token: string): void;
    /**
     * return user obj
     */
    getUser(): IUser;
    /**
     * Load own user obj
     */
    loadUser(): Promise<void>;
    /**
     * Write token to local storage
     */
    private writeToken;
    /**
     * Read token from local storage
     */
    private readToken;
    /**
     * Delete token in local storage
     */
    private deleteToken;
    /**
     * Write token to store and
     * call auth state subject
     */
    private setTokenResponse;
    /**
     * Call API for own user obj
     * and return it
     */
    private requestUser;
    /**
     * Update user
     */
    private updateUser;
    /**
     * Login user and request token
     */
    private postLogin;
    /**
     * Register new user
     */
    private postRegister;
    /**
     * Request password reset
     */
    private postRequestPasswordReset;
    /**
     * Reset password
     */
    private postResetPassword;
    /**
     * Decode token
     */
    private decodeToken;
    static ɵfac: i0.ɵɵFactoryDeclaration<AuthService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AuthService>;
}
